#include <libint2.h>
#ifdef __cplusplus
extern "C" {
#endif
void _aB_H__0__K__1___TwoPRep_H__0__I__1___Ab__up_0(const Libint_t* inteval);
#ifdef __cplusplus
};
#endif
